==> locomotive_booking_plugin-1.0.0.gem: README.md <==
# CustomerCount Plugin for Locomotive
This is a plugin for LocomotiveCMS. It was created to provide unique identifier numbers to the frontend.

## Important
Please note that you need Locomotivecms with the plugin interface provided by Colibri-Software (see https://github.com/colibri-software/locomotive_engine branch: plugin). 
A more recent version can be found here: https://github.com/eilers/locomotive_engine


##  Installation
To install the plugin in LocomotiveCMS, simply [create a LocomotiveCMS
app](http://doc.locomotivecms.com/guides/get-started/install-engine), ensuring
you have all of the [Requirements](http://doc.locomotivecms.com/guides/get-started/requirements) installed, and add your
plugin gem to the app's Gemfile in the `locomotive_plugins` group:

     group(:locomotive_plugins) do
      gem 'locomotive_customercount_plugin'
      gem 'another_plugin'
    end

## Usage

### Configuring Plugin

This plugin provides no configuration menu.

### Liquid Drops

No liquid drops are provided

### Liquid Tags

2 Tags are implemented:

#### booking_putBookings
Stores booking data. The given String needs to be a JSONObject. It will be URL-decoded so that's possible to provide the string inside a query string.
The following parameter needs to be set:
    - booking_data: The JSONObject as a String. Will be URL-decoded.

The Tag returns a JSONObject with a "success"-key that is either true or false.

The JSONObject from the booking_data parameter needs the following keys and values:
    - year: The year under which the booking data should be stored (number)
    - week: The week under which the booking data should be stored (number)
    - weekData: The data to store (array)

It's important to note that the weekData will *not* be checked for a correct format. It will just be stored as it is.

#### booking_getBookings
Reads previously stored booking data. The following parameters need to be set:
    - calendar_year: The year under which to look for the booking data.
    - calendar_week: The week under which to look for the booking data.

The Tag returns either a JSONObject of the same format as booking_putbookings uses or null if no data could be found.

### Liquid Filters

No liquid filters are provided

==> locomotive_booking_plugin-1.1.1.gem: README.md <==
# CustomerCount Plugin for Locomotive
This is a plugin for LocomotiveCMS. It was created to provide unique identifier numbers to the frontend.

## Important
Please note that you need Locomotivecms with the plugin interface provided by Colibri-Software (see https://github.com/colibri-software/locomotive_engine branch: plugin). 
A more recent version can be found here: https://github.com/eilers/locomotive_engine


##  Installation
To install the plugin in LocomotiveCMS, simply [create a LocomotiveCMS
app](http://doc.locomotivecms.com/guides/get-started/install-engine), ensuring
you have all of the [Requirements](http://doc.locomotivecms.com/guides/get-started/requirements) installed, and add your
plugin gem to the app's Gemfile in the `locomotive_plugins` group:

     group(:locomotive_plugins) do
      gem 'locomotive_customercount_plugin'
      gem 'another_plugin'
    end

## Usage

### Configuring Plugin

This plugin provides no configuration menu.

### Liquid Drops

No liquid drops are provided

### Liquid Tags

2 Tags are implemented:

#### booking_putBookings
Stores booking data. The given String needs to be a JSONObject. It will be URL-decoded so that it's possible to provide the string inside a query string.
The following parameter needs to be set:
    - booking_data: The JSONObject as a String. Will be URL-decoded.

The Tag returns a JSONObject with a "success"-key that is either true or false.

The JSONObject from the booking_data parameter needs the following keys and values:
    - resourceId: The resource to connect this booking data to.
    - year: The year under which the booking data should be stored (number)
    - week: The week under which the booking data should be stored (number)
    - weekData: The data to store (array)

It's important to note that the weekData will *not* be checked for a correct format. It will just be stored as it is.

#### booking_getBookings
Reads previously stored booking data. The following parameters need to be set:
    - resource_id: The resource for which the booking data shall be retrieved.
    - calendar_year: The year under which to look for the booking data.
    - calendar_week: The week under which to look for the booking data.

The Tag returns either a JSONObject of the same format as booking_putbookings uses or null if no data could be found.

#### booking_getResources
No parameters

Returns all resources with their _ids and names.

#### booking_putResources
Stores and changes resources. The given String needs to be a JSONObject. It will be URL-decoded so that it's possible to provide the string inside a query string.
The following parameter needs to be set:
    - resource_data: The JSONObject as a String. Will be URL-decoded.

The Tag returns a JSONObject with a "success"-key that is either true or false.

The JSONObject from the resource_data parameter needs the following keys and values:
    - resourceId (String): If you want to change or delete an existing resource, you need to state an id. On the other hand, if you want to create a new resource, this field needs to omitted.
    - resourceName (String): The name of the resource to either change into or use for a new resource that will be created.
    - delete (Boolean): If a resourceId is set and delete is true, the resource will be deleted. In this case the resourceName field is ignored.

### Liquid Filters

No liquid filters are provided
